summaryrefslogtreecommitdiff
path: root/src/lib/encoder.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/encoder.h')
-rw-r--r--src/lib/encoder.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/lib/encoder.h b/src/lib/encoder.h
index 3b8c233bb..8b7c1f3ad 100644
--- a/src/lib/encoder.h
+++ b/src/lib/encoder.h
@@ -98,8 +98,8 @@ private:
/** Number of frames that we should keep history for */
static int const _history_size;
- /** Number of video frames written for the DCP so far */
- int _video_frames_out;
+ /** Number of video frames enqueued so far */
+ int _video_frames_enqueued;
bool _terminate;
std::list<boost::shared_ptr<DCPVideo> > _queue;
@@ -113,6 +113,8 @@ private:
boost::shared_ptr<Writer> _writer;
Waker _waker;
+ boost::shared_ptr<PlayerVideo> _last_player_video;
+
boost::signals2::scoped_connection _server_found_connection;
};